@@ -2,7 +2,6 @@
 
 Functions:
 ensure_dirpath
-ensure_nonduplicate_with_version
 ensure_suffix
 find_file_in_tree
 find_file_in_userdir
@@ -12,7 +11,6 @@ import os
 import pathlib
 
 from eagers.config.user import USER_DIR_EXCLUDE_NAME
-from eagers.config.text import NAME_SEP, VERSION_INDICATOR
 
 
 def ensure_dirpath(filepath):
@@ -36,43 +34,6 @@ def ensure_dirpath(filepath):
     return filepath
 
 
-def ensure_nonduplicate_with_version(filepath, version=None):
-    """Return the given filepath with a new name, if necessary,
-    including a version suffix to ensure it is not a duplicate of an
-    already-existing file.
-
-    Positional arguments:
-    filepath - (pathlib.Path) Path to file.
-
-    Keyword arguments:
-    version - (int) (Default: None) Version number to use. Allows manual
-        specification of a version number.
-    """
-    def new_filepath(filepath, vn):
-        """Return a new filepath with the specified version number."""
-        stem, suffix = filepath.stem, filepath.suffix
-        return filepath.with_name(
-            f"{stem}{NAME_SEP}{VERSION_INDICATOR}{vn}" + suffix
-        )
-    if version is not None:
-        # Version manually specified.
-        filepath = new_filepath(filepath, version)
-        if filepath.exists():
-            raise ValueError(
-                f"Version {version!r} does not create a unique filepath."
-            )
-    if not filepath.exists():
-        # Job's done. No need to worry about versions.
-        return filepath
-    # Add a version suffix and increment the version number until there
-    # is no more duplication.
-    vnum = 2
-    while filepath.exists():
-        filepath = new_filepath(filepath, vnum)
-        vnum += 1
-    return filepath
-
-
 def ensure_suffix(filepath, suffix, remove_bad_suffix=False):
     """Return the given file path, ensuring that it has the given
     suffix. The returned file path has the same data type as the given
