@@ -260,7 +260,7 @@ def check_acdc(gen,net_abbrev):
             for gen_i in gen:
                 if gen_i['type'] == 'ACDCConverter':
                     ac_dc = {}
-                    ac_dc['dc_to_ac_eff'] = gen_i['output']['e'][0][1]
+                    ac_dc['dc_to_ac_eff'] = abs(gen_i['output']['e'][0][-1])
                     ac_dc['ac_to_dc_eff'] = gen_i['output']['dc'][0][0]
             if not ac_dc is None:
                 for i in range(len(gen)):
@@ -287,7 +287,7 @@ def net_marginal_cost(gen,net_abbrev,market,dispatch, scale_cost, dt, v_h):
                     s.append(k)
         if gen_i['type'] == 'ACDCConverter':
             ac_dc = {}
-            ac_dc['dc_to_ac_eff'] = gen_i['output']['e'][0][1]
+            ac_dc['dc_to_ac_eff'] = abs(gen_i['output']['e'][0][-1])
             ac_dc['ac_to_dc_eff'] = gen_i['output']['dc'][0][0]
 
     marginal = {}
@@ -552,7 +552,7 @@ def min_max_cost(gen, include, stor_include, scale, dispatch,s,marginal,dt):
             if s in gen[i]['output']:
                 sc = scale[i]
             elif not ac_dc is None and s == 'e' and 'dc' in gen[i]['output']:
-                sc = [j*ac_dc['output']['e'][0][1] for j in scale[i]]
+                sc = [j*abs(ac_dc['output']['e'][0][-1]) for j in scale[i]]
             elif not ac_dc is None and s == 'dc' and 'e' in gen[i]['output']:
                 sc = [j*ac_dc['output']['dc'][0][0] for j in scale[i]]
             if not sc is None:
