@@ -5,6 +5,7 @@ Classes:
 TimeSeriesDataSet
 NodeDataTimeSeries
 WeatherTimeSeries
+OtherTimeSeries
 """
 
 import calendar
@@ -104,9 +105,6 @@ class TimeSeriesDataSet(DataConstructed):
         and re-open the file in some cases.
         """
         col = 'timestamp'
-        start, stop = cls._handle_start_stop_args(
-            table, start, stop, typecast="float"
-        )
         # Check input integrity.
         assert start <= stop, "Datetime range must be in chronological order."
         # Create query.
@@ -195,6 +193,9 @@ class TimeSeriesDataSet(DataConstructed):
             getting points on either side of timestamp ranges.
         """
         with self.table_context(tablename) as table:
+            start, stop = self._handle_start_stop_args(
+                table, start, stop, typecast="float"
+            )
             return self._read_timestamp_range_from_table(
                 table,
                 start,
@@ -204,6 +205,73 @@ class TimeSeriesDataSet(DataConstructed):
                 return_indices=return_indices,
             )
 
+    def read_timestamp_range_extend_missing(
+        self,
+        tablename,
+        start=None,
+        stop=None,
+        *,
+        field=None,
+    ):
+        """Same as read_timestamp_range(), but extends data to fill missing points if
+        needed. This is not applicable to TMY weather data. Here, there are no
+        `inclusive` (it's always True) or `return_indices` options.
+        """
+        with self.table_context(tablename) as table:
+            start, stop = self._handle_start_stop_args(
+                table, start, stop, typecast="float"
+            )
+            data = self._read_timestamp_range_from_table(
+                table,
+                start,
+                stop,
+                field=field,
+            )
+            timestamp = data["timestamp"]
+            if timestamp.size:
+                first_timestamp = timestamp[0]
+                last_timestamp = timestamp[-1]
+            else:
+                first_timestamp = table.read(0, 1, field="timestamp")[0]
+                last_timestamp = table.read(-1, field="timestamp")[0]
+            need_ante_extension = first_timestamp > start
+            need_post_extension = last_timestamp < stop
+            extension_requirement = need_ante_extension + need_post_extension
+            frequency = None
+            if extension_requirement:
+                assert (
+                    extension_requirement < 2
+                ), "Can't handle both ante- and post-extension."
+                if len(timestamp) > 1:
+                    frequency = np.mean(np.diff(timestamp))
+                else:
+                    frequency = np.diff(table.read(0, 2, field="timestamp"))[0]
+        if frequency is not None:
+            if need_ante_extension:
+                extension_time = first_timestamp - start
+            else:
+                extension_time = stop - last_timestamp
+            assert extension_time >= frequency, (
+                f"Need: extension_time >= frequency. Actual: {extension_time} < "
+                f"{frequency}"
+            )
+            secs_in_day = 3600 * 24
+            if need_ante_extension:
+                new_start = start + secs_in_day
+                new_stop = first_timestamp + secs_in_day - frequency
+            else:
+                new_start = last_timestamp - secs_in_day + frequency
+                new_stop = stop - secs_in_day
+            extension = self.read_timestamp_range(tablename, new_start, new_stop)
+            if need_ante_extension:
+                extension["timestamp"] -= secs_in_day
+                arrays = [extension, data]
+            else:
+                extension["timestamp"] += secs_in_day
+                arrays = [data, extension]
+            data = rfn.stack_arrays(arrays, usemask=False, asrecarray=True)
+        return data
+
 
 class NodeDataTimeSeries(TimeSeriesDataSet):
     def __init__(self, filename):
@@ -255,6 +323,9 @@ class WeatherTimeSeries(TimeSeriesDataSet):
             )
         elif designation == 'tmy':
             with self.table_context(tablename) as table:
+                start, stop = self._handle_start_stop_args(
+                    table, start, stop, typecast="datetime"
+                )
                 return self._tmy_read_timestamp_range(
                     table, start, stop, *args, **kwargs
                 )
@@ -270,28 +341,6 @@ class WeatherTimeSeries(TimeSeriesDataSet):
                 f"Couldn't find a designation for table {tablename!r}"
             )
 
-    def table_designation(self, tablename):
-        """The weather file designation of the table with the given
-        name.
-        """
-        try:
-            return self._des[tablename]
-        except KeyError:
-            raise ValueError(
-                f"Couldn't find a designation for table {tablename!r}"
-            )
-
-    def table_designation(self, tablename):
-        """The weather file designation of the table with the given
-        name.
-        """
-        try:
-            return self._des[tablename]
-        except KeyError:
-            raise ValueError(
-                f"Couldn't find a designation for table {tablename!r}"
-            )
-
     def _tmy_read_timestamp_range(
         self,
         table,
@@ -323,9 +372,6 @@ class WeatherTimeSeries(TimeSeriesDataSet):
             have timestamps from 2017-4-23 to 2017-12-31, then 2017-1-1
             to 2017-7-4.
         """
-        start, stop = self._handle_start_stop_args(
-            table, start, stop, typecast="datetime"
-        )
         # Check for Feb 29 within requested range.  If found, will need
         # to break at occurrences of both Feb 29 and new year.  After
         # initializing an array, append sections of the range between
@@ -483,6 +529,7 @@ class WeatherTimeSeries(TimeSeriesDataSet):
     ):
         """Read a section from the TMY file up to the end of the year.
         """
+        start,stop = self._handle_start_stop_args(table,start,stop,typecast='float')
         result = self._read_timestamp_range_from_table(
             table,
             start,
@@ -507,3 +554,19 @@ class WeatherTimeSeries(TimeSeriesDataSet):
                 ]
             )
         arrays.append(result)
+
+class OtherTimeSeries(TimeSeriesDataSet):
+    def __init__(self, filename):
+        super().__init__(filename, 'other')
+
+    def start_dates(self, as_datetime=False):
+        """Returns an array of the available start dates for this data
+        set.
+
+        Keyword arguments:
+        as_datetime - (bool) (Default: False) Whether to return a list
+            of datetime objects instead of an array of floats.
+        """
+        with self.file_context() as h5f:
+            floats = getattr(h5f.root, 'available_start_dates').read()
+            return DFC.f2d_arr2lst(floats) if as_datetime else floats
\ No newline at end of file
