@@ -2,7 +2,7 @@ import datetime as dt
 
 
 # Types of data sets.
-DATASET_TYPES = ('nodedata', 'weather')
+DATASET_TYPES = ('nodedata', 'weather','other')
 
 # HDF5 table descriptions.
 DATASET_DESCR = dict(
@@ -24,6 +24,9 @@ DATASET_DESCR = dict(
         tot_cld=dict(col='Float32Col', pos=10),
         opq_cld=dict(col='Float32Col', pos=11),
     ),
+    other=dict(timestamp=dict(col='Time64Col', pos=0),
+        e=dict(col='Float64Col', pos=1),
+        ),
 )
 
 # Conversion from shape codes to dimension info field names.
