@@ -2,22 +2,8 @@
 """
 
 
-# MESSAGES
-MSG_DATETIME_FORMAT = "%m/%d/%y %H:%M:%S"
-MSG_DAYS_LEN = 3
-MSG_DESCR_LEN = 40
-MSG_ITER_HALF_LEN = 5
-MSG_SEPARATOR = " | "
-
-
-# FILE NAME INDICATORS
-VERSION_INDICATOR = "v"
-
-
 # NAMES
 # General
-# Name separator.
-NAME_SEP = "_"
 # Prefix for runtime HDF5 files.
 RUNTIME_HDF5_FILE_PREFIX = "runtime_"
 
