@@ -51,10 +51,3 @@ kWh_per_Mcf_natgas = Btu_per_Mcf_natgas / Btu_per_kWh
 
 # MMBtu to kWh.
 kWh_per_MMBtu_natgas = 293.15
-
-
-# REFERENCE VALUES
-
-# Benchmark heat rate (Btu/kWh).
-# https://www.eia.gov/todayinenergy/detail.php?id=9911
-HEAT_RATE_BENCHMARK = 7_000
