@@ -23,9 +23,8 @@ from eagers.config.excel_interface import (
     AUTO_STARTDATE_VALUES, HELP_SECTIONHEADER_WIDTH, HELP_TAB_COLOR, STYLES,
     WORKBOOK_SUFFIX)
 from eagers.config.path_spec import (
-    EPW_SUFFIX, HDF5_SUFFIX, EXCEL_INTERFACE_PROJECT_HELP,
-    USER_DIR_ENERGYPLUS_WEATHER, USER_DIR_HDF5_DATASETS, USER_DIR_LOCATION,
-    USER_DIR_PROJECTS, USER_DIR_TESTDATA,
+    EPW_SUFFIX, HDF5_SUFFIX, EXCEL_INTERFACE_PROJECT_HELP, USER_DIR_HDF5_DATASETS, USER_DIR_LOCATION,
+    USER_DIR_PROJECTS, USER_DIR_TESTDATA,BUILDPLUS_DIR_PATH,
 )
 from eagers.config.text import RUNTIME_HDF5_FILE_PREFIX
 from eagers.extras import bplus_load_building
@@ -138,8 +137,7 @@ class ProjectTemplateWriter(ProjectTemplateHandler, BaseTemplateWriter):
 
     # Sheet order makes up for the lack of ordering in dictionaries
     # (changed in Python 3.7: dict class now remembers insertion order).
-    _sheet_order = ['Components', 'Buildings', 'FluidLoops', 'Network',
-        'TimeSeriesInputs', 'Instructions']
+    _sheet_order = ['Components', 'Buildings', 'FluidLoops', 'Network','Options']
     _sheet_properties = {
         'Components': dict(
             add_method='_build_components_sheet',
@@ -153,12 +151,8 @@ class ProjectTemplateWriter(ProjectTemplateHandler, BaseTemplateWriter):
         'Network': dict(
             add_method='_build_network_sheet',
         ),
-        'TimeSeriesInputs': dict(
-            add_method='_build_timeseriesinputs_sheet',
-        ),
-        'Instructions': dict(
-            tab_color=HELP_TAB_COLOR,
-            add_method='_build_help_sheet',
+        'Options': dict(
+            add_method='_build_options_sheet',
         ),
     }
 
@@ -550,9 +544,10 @@ class ProjectTemplateReader(ProjectTemplateHandler, BaseTemplateReader):
                 sheetname, h = h.split(':')
                 v_split = v.split(',')
                 ts_header, data_header = v_split[0].strip(), v_split[1].strip()
-                time, values = cls._read_timeseries_input(
-                    wb[sheetname], ts_header, data_header)
-                info = {'timestamp': time, h: values}
+                info = {'timestamp': ts_header, h: data_header}
+                # time, values = cls._read_timeseries_input(
+                #     wb[sheetname], ts_header, data_header)
+                # info = {'timestamp': time, h: values}
             else:
                 info = {h: interpret_value(v)}
             if None not in info.values():
@@ -594,6 +589,9 @@ class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
         'Weather': dict(
             read_method='_read_weather_sheet',
         ),
+        'Other': dict(
+            read_method='_read_other_sheet'
+        )
     }
     _user_cache_name = 'test_data'
 
@@ -652,6 +650,7 @@ class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
                 TIMESTAMP_RESOLUTION_TABLENAMES[ts_resolution]: dict(
                     designation=designation,
                     data=weather_data,
+                    n_row=len(weather_data['timestamp'])
                 ),
             }
 
@@ -696,8 +695,6 @@ class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
         values = ws.values
         # First row is headers.
         headers = next(values)
-        hydro_only_headers = \
-            {'inflow', 'outflow', 'inflow_history', 'outflow_history'}
         # Read remaining rows as data.
         tsi_headers = {}
         network_info = {}
@@ -715,15 +712,6 @@ class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
                 if len(row) > 1:
                     # More than just a network name.
                     row_data = dict(zip(headers, row))
-                    # Check hydro-specific data requirements.
-                    # hydro_check = row_data['network'] == 'hydro' \
-                    #     and set(row_data.keys()) == set(headers)
-                    nonhydro_check = net != 'hydro' \
-                        and not (set(row_data.keys())
-                            .intersection(hydro_only_headers))
-                    assert nonhydro_check, \
-                        ("Hydro-specific data must be found only in only hydro"
-                        "network rows.")
                     # Append to set of TimeSeriesInputs headers.
                     for k, v in row_data.items():
                         if ',' not in v:
@@ -781,6 +769,49 @@ class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
             designation=designation,
             filename=None,
         )
+    @classmethod
+    def _read_other_sheet(cls, wb, ws):
+        """Read the given node data Worksheet."""
+        # Get worksheet values generator.
+        values = ws.values
+        # First row is headers.
+        headers = next(values)
+        # Read remaining rows as data.
+        tsi_headers = {}
+        object_info = {}
+        for row in values:
+            if cls._is_empty(row):
+                # Blank row.  Do nothing.
+                continue
+            else:
+                row = cls._rstrip_nones(row)
+                if not row[0] is None:
+                    net = row[0]
+                else:
+                    row = list(row)
+                    row[0] = net
+                if len(row) > 1:
+                    # More than just a object name.
+                    row_data = dict(zip(headers, row))
+                    # Append to set of TimeSeriesInputs headers.
+                    for k, v in row_data.items():
+                        if ',' not in v:
+                            continue
+                        tstamp, field = v.replace(' ', '').split(',')
+                        try:
+                            tsi_headers[tstamp].add(field)
+                        except KeyError:
+                            tsi_headers[tstamp] = {field}
+                        row_data[k] = (tstamp, field)
+                    # Append to list of node data.
+                    try:
+                        object_info[row_data['object']].append(row_data)
+                    except KeyError:
+                        object_info[row_data['object']] = [row_data]
+        return dict(
+            tsi_headers=tsi_headers,
+            object_info=object_info,
+        )
 
     @classmethod
     def _read_weatherfile_data(cls, filename, designation):
@@ -792,13 +823,21 @@ class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
                 )
             except FileNotFoundError:
                 weather_data = read_weather_file(
-                    ensure_suffix(USER_DIR_ENERGYPLUS_WEATHER / filename, EPW_SUFFIX),
+                    BUILDPLUS_DIR_PATH /'eplus_weather' / ensure_suffix(filename, EPW_SUFFIX),
                     designation,
                 )
             return weather_data
 
     @classmethod
     def _read_timeseriesinputs_header_info(cls, ws, sheet_data):
+        def table_length(ws,col):
+            n_pts = 0
+            for i,row in enumerate(ws.iter_rows(min_row=2, values_only=True)):
+                if row[col] is None:
+                    break
+                else:
+                    n_pts+=1
+            return n_pts
         tsi_headers = cls._rstrip_nones([c.value for c in ws['1']])
         # Indices must be sorted so that read order matches column order
         # in the HDF5 file.
@@ -822,9 +861,11 @@ class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
                     ((i, h) for i, h in enumerate(tsi_headers) if h in h_cat),
                     key=lambda x: x[0],
                 ))
+                n_pts = table_length(ws,tsi_headers.index(tablename))
                 table_info[cat][tablename] = dict(
                     indices=i_sorted,
                     names=h_sorted,
+                    n_row = n_pts,
                 )
                 if cat == 'weather':
                     table_info[cat][tablename]['designation'] = \
@@ -858,11 +899,10 @@ class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
         return table_descriptions
 
     @classmethod
-    def _gather_data_rows(cls, ws, i_headers, dtype):
+    def _gather_data_rows(cls, ws, n_pts, i_headers, dtype):
         """Returns a structured array of data values for a given set of
         headers.
         """
-        n_pts = ws.max_row - 1
         data = np.empty(dtype=dtype, shape=n_pts)
         timestamp = np.empty(dtype='O', shape=n_pts)
         i_headers = np.array(i_headers)
@@ -871,7 +911,7 @@ class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
         i_ts = i_headers[np.invert(non_ts)][0]
         # ReadOnlyWorksheet does not have iter_cols().  Use
         # iter_rows().
-        for i, row in enumerate(ws.iter_rows(min_row=2, values_only=True)):
+        for i, row in enumerate(ws.iter_rows(min_row=2, max_row = n_pts+1, values_only=True)):
             row = cls._rstrip_nones(row)
             data[i] = (0, *(row[j] for j in i_non_ts))
             timestamp[i] = datetime_from_data(row[i_ts])
@@ -887,18 +927,11 @@ class TestDataTemplateReader(TestDataTemplateHandler, BaseTemplateReader):
             new_hdf5_file(file_info[cat]['file'], overwrite=True)
             for table, h_info in data.items():
                 if from_tsi[cat]:
-                    records = cls._gather_data_rows(
-                        ws,
-                        h_info['indices'],
-                        table_descriptions[cat][table],
-                    )
+                    records = cls._gather_data_rows(ws,h_info['n_row'],h_info['indices'],table_descriptions[cat][table])
                 else:
-                    # Use a key, not a value; that would copy all the
-                    # data into a list.
-                    rando_key = list(h_info['data'].keys())[0]
                     records = np.empty(
                         dtype=table_descriptions[cat][table],
-                        shape=len(h_info['data'][rando_key]),
+                        shape=h_info['n_row'],
                     )
                     for k, v in h_info['data'].items():
                         if k == 'timestamp':
