@@ -1,13 +1,14 @@
 from eagers.basic.result_template import result_template
 from eagers.basic.get_data import get_weather
 from eagers.extras import bplus_building_warmup, bplus_warm_up_date
-from eagers.update.dispatch_record import  record_initial_conditions
 
-def initialize_observer(gen,subnet,fluid_loop,all_data_nodes,names, zones, pl,test_data,building_observer,ic,stor_perc,date,data_t0,project_name):
+
+def initialize_observer(fluid_loop,market,all_data_nodes,names, zones, pl,building_observer,date):
     #operating state of generators, buildings, and fluid loops
     observer = {}
     observer['future'] = result_template(all_data_nodes,names, zones, pl)
     observer['history'] = result_template(all_data_nodes,names, zones, pl)
+    observer['market'] = market
     n_g = len(names['components'])
     n_l = len(names['lines'])
     observer['timestamp'] = date
@@ -17,23 +18,7 @@ def initialize_observer(gen,subnet,fluid_loop,all_data_nodes,names, zones, pl,te
     observer['stor_state'] = [0 for i in range(n_g)]
     observer['line_names'] = names['lines']
     observer['line_flow'] = [0 for i in range(n_l)]
-    lb =  [0 for i in range(n_g)]
-    l1 = ['ElectricGenerator','CombinedHeatPower','Chiller','Heater','Electolyzer','HydrogenGenerator','CoolingTower']
-    l2 = ['ElectricStorage','ThermalStorage','HydrogenStorage']
-    for i in range(n_g):
-        observer['gen_state'][i] = ic[i]
-        if gen[i]['type'] in l1:
-            states = gen[i]['states'][-1]
-            for j in range(len(states)):
-                lb[i] +=gen[i][states[j]]['lb'][-1]
-            if ic[i]<lb[i]:
-                observer['gen_status'][i] = False
-        elif gen[i]['type'] in l2:
-            observer['stor_state'][i] = stor_perc/100 * gen[i]['stor']['usable_size']
-        elif gen[i]['type'] == 'HydroStorage':
-            observer['stor_state'][i] = gen[i]['start_wy']*gen[i]['stor']['usable_size']
-        else:
-            observer['gen_state'][i] = ic[i]
+    
     b_keys = list(building_observer.keys())
     for k in b_keys:
         observer[k] = building_observer[k]
@@ -46,9 +31,6 @@ def initialize_observer(gen,subnet,fluid_loop,all_data_nodes,names, zones, pl,te
         observer['fluid_loop_capacitance'][i] = fluid_loop['fluid_capacity'][i]*fluid_loop['fluid_capacitance'][i] #Water capacity in kg and thermal capacitance in kJ/kg*K to get kJ/K
     observer['hydro_wy_timestamp'] = None
     observer['hydro_wy_soc'] = None
-    
-    dispatch = result_template(all_data_nodes,names, zones, pl)
-    record_initial_conditions(data_t0, dispatch, subnet, observer, project_name)
     return observer
 
 def initialize_building_observer(buildings,test_weather,date):
@@ -98,4 +80,25 @@ def initialize_building_observer(buildings,test_weather,date):
     else:
         zones = [0]
         pl = [0]
-    return observer,zones,pl
\ No newline at end of file
+    return observer,zones,pl
+
+def observer_component_ic(gen,ic,stor_perc,names,observer):
+    n_g = len(names['components'])
+    lb =  [0 for i in range(n_g)]
+    l1 = ['ElectricGenerator','CombinedHeatPower','Chiller','Heater','Electolyzer','HydrogenGenerator','CoolingTower']
+    l2 = ['ElectricStorage','ThermalStorage','HydrogenStorage']
+    for i in range(n_g):
+        observer['gen_state'][i] = ic[i]
+        if gen[i]['type'] in l1:
+            states = gen[i]['states'][-1]
+            for j in range(len(states)):
+                lb[i] +=gen[i][states[j]]['lb'][-1]
+            if ic[i]<lb[i]:
+                observer['gen_status'][i] = False
+        elif gen[i]['type'] in l2:
+            observer['stor_state'][i] = stor_perc/100 * gen[i]['stor']['usable_size']
+        elif gen[i]['type'] == 'HydroStorage':
+            observer['stor_state'][i] = gen[i]['start_wy']*gen[i]['stor']['usable_size']
+        else:
+            observer['gen_state'][i] = ic[i]
+    return observer
\ No newline at end of file
