@@ -34,7 +34,7 @@ def load_matrices(gen, b_names, fluid_loop, market, subnet, options, op, dt):
     for net in subnet['network_names']:
         qp['organize']['names'].extend([subnet[net]['line']['node1'][i] +'_to_' + subnet[net]['line']['node2'][i] for i in range(len(subnet[net]['line']['node1']))])
     qp['organize']['names'].extend(b_names)
-    qp['organize']['names'].extend([fluid_loop[i].name for i in range(n_fl)])
+    qp['organize']['names'].extend([fluid_loop[i]['name'] for i in range(n_fl)])
 
     if dt !=None:
         n_s = len(dt)
@@ -290,7 +290,10 @@ def count_states(gen_all, subnet, options, n_g, n_b, n_l, fluid_loop, dt, x_l, o
             qp['organize']['out_vs_state'][i] = [1,-1]
         elif gen['type'] == 'ACDCConverter':
             # Value is the total transfer from AC to DC.
-            qp['organize']['out_vs_state'][i] = [1,-1]
+            if len(gen['output']['e'][0])==1:
+                qp['organize']['out_vs_state'][i] = [1]
+            else:
+                qp['organize']['out_vs_state'][i] = [1,-1]
         elif gen['type'] in ['Storage','ThermalStorage','ElectricStorage','HydrogenStorage']:
             # Output state for storage is only state of charge
             # (power in the case of hydro).
@@ -344,8 +347,8 @@ def count_states(gen_all, subnet, options, n_g, n_b, n_l, fluid_loop, dt, x_l, o
         qp['indices'][n_g+n_l+n_b+i][0] = [x_l] #output state for fluid loop is temperature
         qp['organize']['out_vs_state'][n_g+n_l+n_b+i] = [1]
         x_l += 1 # 1 states: Temperature of return water
-        lb.append(fluid_loop[i].nominal_return_temperature-fluid_loop[i].temperature_range) #Temperature in C
-        ub.append(fluid_loop[i].nominal_return_temperature+fluid_loop[i].temperature_range) #Temperature in C
+        lb.append(fluid_loop[i]['nominal_return_temperature']-fluid_loop[i]['temperature_range']) #Temperature in C
+        ub.append(fluid_loop[i]['nominal_return_temperature']+fluid_loop[i]['temperature_range']) #Temperature in C
     return qp, lb, ub
 
 
@@ -1105,9 +1108,9 @@ def fluid_loop_constraints(gen, fluid_loop, subnet, a_eq, amat, h, f, organize,
     
     for i in range(n_fl):
         #first order temperature model: 0 = -T(k) +T(k-1) +dt/capacitance*(energy balance)
-        capacitance = fluid_loop[i].fluid_capacity*fluid_loop[i].fluid_capacitance #water capacity in kg and thermal capacitance in kJ/kgK to get kJ/K
-        delta_temperature = fluid_loop[i].nominal_supply_temperature - fluid_loop[i].nominal_return_temperature
-        pump_power = fluid_loop[i].pump_power_per_kgs/(delta_temperature*fluid_loop[i].fluid_capacitance) # (kW_e/kgs) / (K *  (kJ_t/kg*K)) = kW_e/kW_t 
+        capacitance = fluid_loop[i]['fluid_capacity']*fluid_loop[i]['fluid_capacitance'] #water capacity in kg and thermal capacitance in kJ/kgK to get kJ/K
+        delta_temperature = fluid_loop[i]['nominal_supply_temperature'] - fluid_loop[i]['nominal_return_temperature']
+        pump_power = fluid_loop[i]['pump_power_per_kgs']/(delta_temperature*fluid_loop[i]['fluid_capacitance']) # (kW_e/kgs) / (K *  (kJ_t/kg*K)) = kW_e/kW_t 
         c_list = [equip_names.index(equip) for equip in subnet['cooling_water']['equipment'][i] if gen[equip_names.index(equip)]['type'] == 'Chiller']
         if n_s>0:
             for t in range(n_s):
