@@ -12,6 +12,7 @@ def load_network(network, gen, buildings):
     """
 
     subnet = {}
+    read_network(network)
     n_nodes = len(network)
     node_names = []
     location = []
@@ -256,4 +257,24 @@ def add_river_segments(network,gen,subnet,line_number,location,node_names):
     subnet['hydro']['up_river'] = []
     for i in range(len(subnet['hydro']['nodes'])):
         subnet['hydro']['up_river'].append(down_river.index(hydro_node[i])) #finds which nodes the current node is downstream of
-    return subnet
\ No newline at end of file
+    return subnet
+
+def read_network(network):
+    ''' interpret network  information'''
+    con = ['node_name','line_limit','line_efficiency']
+    for net_i in network:
+        if not 'equipment' in net_i:
+            net_i['equipment'] = None
+        if not 'buildings' in net_i:
+            net_i['buildings'] = None
+        if 'location' not in net_i:
+            net_i['location'] = {'latitude': net_i['latitude'],'longitude': net_i['longitude'],'time_zone': net_i['time_zone']}
+        if any(['Connexn' in h for h in list(net_i.keys())]):
+            net_i['connections'] = {'node_name': [], 'line_limit': [], 'line_efficiency': []}
+            headers = [h for h in list(net_i.keys()) if 'Connexn' in h]
+            for h in headers:
+                for c in con:
+                    if c in h:
+                        net_i['connections'][c].append(net_i.pop(h))
+        else:
+            net_i['connections'] = {'node_name': None, 'line_limit': None, 'line_efficiency': None}
\ No newline at end of file
