@@ -14,6 +14,10 @@ def preload(plant,test_data,options,online=None):
     building_qp_form = add_buildings(plant['building'], subnet, gen_qp_form)
     gen_qp_form = check_ac_dc(gen_qp_form, building_qp_form, test_data)
     b_names = [plant['building'][i]['name'] for i in range(len(plant['building']))]
+    if 'fluid_loop' not in plant:
+        plant['fluid_loop'] = []
+    if 'market' not in plant:
+        plant['market'] = []
     op_mat_a = load_matrices(gen_qp_form, b_names, plant['fluid_loop'], plant['market'], subnet, options, 'a', dt)
     op_mat_b = load_matrices(gen_qp_form, b_names, plant['fluid_loop'], plant['market'], subnet, options, 'b', dt)
     one_step = load_matrices(gen_qp_form, b_names, plant['fluid_loop'], plant['market'], subnet, options, 'b', None)
