@@ -27,7 +27,7 @@ load_solar
 
 import numpy as np
 
-from eagers.config.network import NETWORK_NAME_ABBR_MAP, OUTPUT_NETWORK_MAP
+from eagers.config.network import NETWORK_NAME_ABBR_MAP, OUTPUT_NETWORK_ABBR_MAP, OUTPUT_NETWORK_NAME_MAP, NETWORK_NAMES, OUTPUT_NAMES
 from eagers.basic.ss_response import ss_response
 from eagers.solver.ecos_ls import ecos_ls
 
@@ -41,8 +41,8 @@ def update_qpform_all(generator, subnet, test_data, scale_time):
     n = 5  # Number of segments in piecewise quadratic fits.
     qpform = [{}] * n_g
     for i, gen in enumerate(generator):
-        if gen['_type'] in ['RTUtilityElectric','RTUtilityDiesel','RTUtilityCool','RTUtilityHeat','RTUtilityNatgas','TSUtilityElectric','TSUtilityDiesel','TSUtilityCool','TSUtilityHeat','TSUtilityNatgas']:
-            qpform[i] = load_utility(gen)
+        if 'RTUtility' in gen['_type'] or 'TSUtility' in gen['_type']:
+            qpform[i] = load_utility(gen,subnet['network_names'])
         elif gen['_type'] == 'Tradepoint':
             qpform[i] = load_tradepoint(gen)
         elif gen['_type'] == 'Market':
@@ -51,19 +51,8 @@ def update_qpform_all(generator, subnet, test_data, scale_time):
                 'Heater', 'CoolingTower', 'Electrolyzer', 'HydrogenGenerator']:
             max_seg = max([1,min([n,len(gen['output']['capacity'])-3])])
             qpform[i] = load_piecewise(gen, max_seg)
-            if gen['_type'] in ['ElecGeneratorAC', 'CombHeatPowerAC']:
-                gen['lower_bound'] = gen['startup']['electricity'][-1]
-            elif gen['_type'] in ['ElecGeneratorDC', 'CombHeatPowerDC']:
-                gen['lower_bound'] = gen['startup']['direct_current'][-1]
-            elif gen['_type'] in ['Chiller']:
-                gen['lower_bound'] = gen['startup']['cooling'][-1]
-            elif gen['_type'] in ['Heater']:
-                gen['lower_bound'] = gen['startup']['heat'][-1]
-            elif gen['_type'] in ['CoolingTower']:
-                gen['lower_bound'] = gen['startup']['heat_reject'][-1]
-            elif gen['_type'] in ['Electrolyzer', 'HydrogenGenerator']:
-                gen['lower_bound'] = gen['startup']['hydrogen'][-1]
-            ramp_rate = ss_response(gen['size_kw'], gen['lower_bound'],gen['ramp_rate'],gen['state_space']['a'],gen['state_space']['b'],gen['state_space']['c'],gen['state_space']['d'])
+            gen['lower_bound'] = gen_lb(gen['_type'],gen['startup'])
+            ramp_rate = ss_response(gen)
             ramp_rate = ramp_rate/scale_time
             qpform[i]['ramp'] = {}
             qpform[i]['ramp']['b'] = [ramp_rate for j in range(2)] # [ramp up, ramp down]
@@ -85,7 +74,6 @@ def update_qpform_all(generator, subnet, test_data, scale_time):
             qpform[i]['source'] = gen['source']
         qpform[i]['enabled'] = True
         
-
     max_ac_gen, max_dc_gen = max_ac_dc_gen(subnet,qpform)
     qpform = update_utility_sellback_limit(qpform,test_data,max_ac_gen, max_dc_gen)
     qpform = locate_rivers(subnet,qpform)
@@ -100,7 +88,7 @@ def assign_type(gen):
         gen_type = 'CombinedHeatPower'
     elif gen['_type'] in ['ElecGeneratorAC', 'ElecGeneratorDC']:
         gen_type = 'ElectricGenerator'
-    elif gen['_type'] in ['RTUtilityCool','RTUtilityDiesel','RTUtilityElectric','RTUtilityHeat', 'RTUtilityNatgas', 'TSUtilityCool','TSUtilityDiesel','TSUtilityElectric','TSUtilityHeat', 'TSUtilityNatgas']:
+    elif 'RTUtility' in gen['_type'] or 'TSUtility' in gen['_type']:
         gen_type = 'Utility'
     else:
         gen_type = gen['_type']
@@ -157,24 +145,14 @@ def locate_rivers(subnet,qpform):
                         qpform[gen_i]['hydro']['downriver'] = subnet['hydro']['line_number'][n][0]
     return qpform
 
-def load_utility(gen):
+def load_utility(gen,nn):
+    
     qpform = {}
-    if 'Electric' in gen['_type']:
-        gen['source'] = 'electricity'
-    elif 'Heat' in gen['_type']:
-        gen['source'] = 'heat'
-    elif 'Cool' in gen['_type']:
-        gen['source'] ='cooling'
-    elif 'Coal' in gen['_type']:
-        gen['source'] = 'coal'
-    elif 'Natgas' in gen['_type']:
-        gen['source'] ='ng'
-    elif 'Diesel' in gen['_type']:
-        gen['source'] = 'diesel'
-    else:
-        gen['source'] ='nuclear'
+    if not 'source' in gen:
+        gen['source'] = legacy_utility_source(gen['_type'])
+
     qpform['source'] = gen['source']
-    if not gen['source'] in ['ng', 'diesel','coal','nuclear']:# gen is not a fuel utility.
+    if gen['source'] in OUTPUT_NAMES and NETWORK_NAMES[OUTPUT_NAMES.index(gen['source'])] in nn: # gen is not a fuel utility.
         # No sellback allowed (only 1 state).
         qpform['output'] = {}
         qpform['states'] = [['x']]
@@ -184,12 +162,7 @@ def load_utility(gen):
         
         qpform['x']['ub'] = float('inf')
         qpform['ub'] = float('inf')
-        if gen['source'] == 'electricity':
-            s = 'e'
-        elif gen['source'] == 'heat':
-            s = 'h'# Loads the parameters for a distric heating supply.
-        elif gen['source'] == 'cooling':
-            s = 'c'# Loads the parameters for a distric cooling supply.
+        s = OUTPUT_NETWORK_ABBR_MAP[gen['source']]
         qpform['output'][s] = [[1]]
         if 'min_import_thresh' in gen:
             qpform['x']['lb'] = gen['min_import_thresh']
@@ -224,6 +197,23 @@ def load_utility(gen):
         qpform[k] = gen[k]
     return qpform
 
+def legacy_utility_source(u_type):
+    if 'Electric' in u_type:
+        source = 'electricity'
+    elif 'Heat' in u_type:
+        source = 'heat'
+    elif 'Cool' in u_type:
+        source ='cooling'
+    elif 'Coal' in u_type:
+        source = 'coal'
+    elif 'Natgas' in u_type:
+        source ='ng'
+    elif 'Diesel' in u_type:
+        source = 'diesel'
+    else:
+        source ='nuclear'
+    return source
+
 def load_market(market):
     qpform = {}
     qpform['states'] = [['x']]
@@ -246,6 +236,7 @@ def load_market(market):
     return qpform
 
 def load_tradepoint(t_point):
+    ##TODO b0, b1, etc are time series and need to be updated in matrices
     qpform = {}
     qpform['six_param'] = [t_point.b0,t_point.b1,t_point.max_buy,t_point.s0,t_point.s1,t_point.max_sell]
     qpform['states'] = [['x','y']]
@@ -368,7 +359,7 @@ def load_piecewise(gen, n):
             n_b += 1
     qpform['states'] = [[],[]]
     if gen['_type'] == 'Chiller':
-        net = OUTPUT_NETWORK_MAP[gen['source']]
+        net = OUTPUT_NETWORK_NAME_MAP[gen['source']]
         source = NETWORK_NAME_ABBR_MAP[net]
         if source == 'h':
             # Absorption chiller has no direct electrical load, but later pump for cooling tower can be added.
@@ -410,7 +401,7 @@ def remove_segments(a, n, x_max, order, co_prod):
     tol = 1e-2
     keep = [True for i in range(order*n)]
     for i in range(1, n):
-        if (((a[i]==0 and a[i-1]==0) and (a[i-1]!=0 and abs((a[i] - a[i-1])/a[i-1]) < tol))
+        if (((a[i]==0 and a[i-1]==0) or (a[i-1]!=0 and abs((a[i] - a[i-1])/a[i-1]) < tol))
                 and (order == 1 or a[n+i]*x_max[i] < tol*a[i-1])
                 and (co_prod is None or abs((co_prod[i] - co_prod[i-1])/co_prod[i-1]) < tol)):
             keep[i] = False
@@ -486,20 +477,26 @@ def load_storage(gen, scale_time):
     else:
         # Electric battery.
         qpform['output']['dc'] = [[1]]
-        stor['voltage'] = gen['voltage']
-        disch_current = gen['peak_disch'] * gen['size_kwh'] / stor['voltage'] * 1000
-        # Scale so the loss of power is equivelant to that specified at 100 Amps.
-        stor['disch_resist_scaled'] = (100 / disch_current) * gen['disch_resist'] / 1000
-        # Keep in mind when calculating loss as function of discharge current.
-        disch_volt_loss = disch_current * stor['disch_resist_scaled']
-        charge_current = gen['peak_charge'] * gen['size_kwh'] / stor['voltage'] * 1000
-        # Scale so the loss of power is equivelant to that specified at 10 Amps.
-        stor['charge_resist_scaled'] = (100/charge_current) * gen['charge_resist'] / 1000
-        charge_volt_loss = charge_current * stor['charge_resist_scaled']
-        stor['charge_eff'] = stor['voltage'] / (stor['voltage'] + charge_volt_loss)
-        stor['disch_eff'] = (stor['voltage'] - disch_volt_loss) / stor['voltage']
-        stor['peak_disch'] = disch_current * stor['voltage'] * stor['disch_eff'] / 1000 # Peak discharge power [kW out].
-        stor['peak_charge'] = charge_current * stor['voltage'] / stor['charge_eff'] / 1000  # Peak charge power [kW in].
+        # Can be specified by voltage and charge/discharge resistances or by
+        # charge/discharge efficiencies and peak charge/discharge power.
+        stor_fields = ('charge_eff', 'disch_eff', 'peak_charge', 'peak_disch')
+        if any(x not in gen for x in stor_fields):
+            voltage = gen['voltage']
+            disch_current = gen['peak_disch'] * gen['size_kwh'] / voltage * 1000
+            # Scale so the loss of power is equivelant to that specified at 100 Amps.
+            disch_resist_scaled = (100 / disch_current) * gen['disch_resist'] / 1000
+            # Keep in mind when calculating loss as function of discharge current.
+            disch_volt_loss = disch_current * disch_resist_scaled
+            charge_current = gen['peak_charge'] * gen['size_kwh'] / voltage * 1000
+            # Scale so the loss of power is equivelant to that specified at 10 Amps.
+            charge_resist_scaled = (100/charge_current) * gen['charge_resist'] / 1000
+            charge_volt_loss = charge_current * charge_resist_scaled
+            stor['charge_eff'] = voltage / (voltage + charge_volt_loss)
+            stor['disch_eff'] = (voltage - disch_volt_loss) / voltage
+            stor['peak_disch'] = disch_current * voltage * stor['disch_eff'] / 1000 # Peak discharge power [kW out].
+            stor['peak_charge'] = charge_current * voltage / stor['charge_eff'] / 1000  # Peak charge power [kW in].
+        else:
+            stor.update({x: gen[x] for x in stor_fields})
     qpform['stor'] = stor
     # qpform['ramp_rate'] = [stor['peak_disch'],stor['peak_charge']]  # Storage discharge constraint [kW].
     qpform['states'] = [['x']] # State of charge, charging power, no buffers.
@@ -616,23 +613,30 @@ def load_hydro_storage(gen, scale_time):
 
 def load_ac_dc(gen):
     """Load AC/DC generator."""
+    # First state is AC power transferred to DC power.
+    # Second state is DC power transferred to AC power.
+    # Unless perfect, then just 1 state
     qpform = {}
     qpform['output'] = {}
     qpform['a'] = {}
-    qpform['b'] = {}
-    # First state is AC power transferred to DC power.
-    # Second state is DC power transferred to AC power.
-    qpform['states'] = [['a','b']]
-    qpform['output']['e'] = [[-1, gen['dc_to_ac_eff']]]
-    qpform['output']['dc'] = [[gen['ac_to_dc_eff'], -1]]
     qpform['a']['ub'] = gen['capacity']
-    qpform['a']['lb'] = 0
     qpform['a']['f'] = 0
     qpform['a']['h'] = 0
-    qpform['b']['ub'] = gen['capacity']
-    qpform['b']['lb'] = 0
-    qpform['b']['f'] = 0
-    qpform['b']['h'] = 0
+    if gen['dc_to_ac_eff']==1 and gen['ac_to_dc_eff']==1:
+        qpform['a']['lb'] = -gen['capacity']
+        qpform['output']['e'] = [[-1]]
+        qpform['output']['dc'] = [[1]]
+        qpform['states'] = [['a']]
+    else:
+        qpform['a']['lb'] = 0
+        qpform['output']['e'] = [[-1, gen['dc_to_ac_eff']]]
+        qpform['output']['dc'] = [[gen['ac_to_dc_eff'], -1]]
+        qpform['states'] = [['a','b']]
+        qpform['b'] = {}
+        qpform['b']['ub'] = gen['capacity']
+        qpform['b']['lb'] = 0
+        qpform['b']['f'] = 0
+        qpform['b']['h'] = 0
     return qpform
 
 
@@ -752,7 +756,7 @@ def fit_coproduction(gen, a, b, n):
     fuel_input = []
     seg_heat = []
     for j in range(len(seg_end)):
-        while cap[i+1]<seg_end[j]/ub:
+        while seg_end[j]/ub - cap[i+1]>1e-6:
             i+=1
         r = (cap[i+1]-seg_end[j]/ub)/(cap[i+1]-cap[i])
         fuel_input.append(r*seg_end[j]/elec[i] + (1-r)*seg_end[j]/elec[i+1])
@@ -951,7 +955,10 @@ def update_utility_sellback_limit(qpform,test_data,max_ac_gen, max_dc_gen):
                 qpform[i]['y']['ub'] = max_ac_gen + max_dc_gen
         if qpform[i]['type']=='ACDCConverter':
             qpform[i]['a']['ub'] = max_ac_gen
-            qpform[i]['b']['ub'] = max_dc_gen
+            if 'b' in qpform[i]:
+                qpform[i]['b']['ub'] = max_dc_gen
+            else:
+                qpform[i]['a']['lb'] = -max_dc_gen
     return qpform
 
 def load_solar(gen,subnet):
@@ -984,4 +991,19 @@ def load_solar(gen,subnet):
             if gen['name'] in subnet['electrical']['equipment'][n]:
                 qpform['location'] = subnet['electrical']['location'][n]
                 break
-    return qpform
\ No newline at end of file
+    return qpform
+
+def gen_lb(gtype,gstart):
+    if gtype in ['ElecGeneratorAC', 'CombHeatPowerAC']:
+        lb = gstart['electricity'][-1]
+    elif gtype in ['ElecGeneratorDC', 'CombHeatPowerDC']:
+        lb = gstart['direct_current'][-1]
+    elif gtype in ['Chiller']:
+        lb = gstart['cooling'][-1]
+    elif gtype in ['Heater']:
+        lb = gstart['heat'][-1]
+    elif gtype in ['CoolingTower']:
+        lb = gstart['heat_reject'][-1]
+    elif gtype in ['Electrolyzer', 'HydrogenGenerator']:
+        lb = gstart['hydrogen'][-1]
+    return lb
\ No newline at end of file
