@@ -20,7 +20,6 @@ mp_test_more_cases
 """
 
 from eagers.basic.gen_limit import gen_limit, chp_heat
-from eagers.update.update_cost import update_cost
 from eagers.basic.marginal_cost import gen_marginal_cost, sort_mc, net_marginal_cost
 from eagers.update.disable_gen import disable_gen
 from eagers.solver.ecos_qp import ecos_qp
@@ -415,7 +414,7 @@ def alt_generation(qp, gen, market, subnet, options, first_profile, stor_power,
     for i in range(n_g):
         if gen[i]['type'] == 'ACDCConverter':
             acdc = True
-            dc_ac = gen[i]['output']['e'][0][1]
+            dc_ac = abs(gen[i]['output']['e'][0][-1])
             ac_dc = gen[i]['output']['dc'][0][0]
     if gen[k]['type'] == 'Chiller':
         out = 'c'
