@@ -220,14 +220,17 @@ def ac_dc_prod(net, qp, row, states, ac_dc, gen, step_profile, dt):
         # Capacity to convert AC to DC power.
         min_prod = -gen[ac_dc]['a']['ub']
         # Pull out the DC/AC conversion efficiency.
-        max_prod = qp['a_eq'][row][states[1]] * tot_dc
+        max_prod = abs(qp['a_eq'][row][states[-1]]) * tot_dc
     elif net == 'direct_current':
         # Need only the row corresponding to the node that this generator is on.
         row_ac = qp['organize']['balance']['electrical']
         _, max_prod_ac = check_feas(gen, qp, row_ac, step_profile, dt,'electrical')
         tot_ac = sum([max_prod_ac[k] for k in range(len(gen))])
         # Capacity to convert DC to AC power.
-        min_prod = -gen[ac_dc]['b']['ub']
+        if 'b' in gen[ac_dc]:
+            min_prod = -gen[ac_dc]['b']['ub']
+        else:
+            min_prod = gen[ac_dc]['a']['lb']
         # Pull out the AC/DC conversion efficiency.
         max_prod = qp['a_eq'][row][states[0]] * tot_ac
     return min_prod, max_prod
