@@ -12,7 +12,7 @@ update_mat_market
 """
 
 
-def update_matrices(gen, observer, market, subnet, options, qp, date, scale_cost,
+def update_matrices(gen, observer, subnet, options, qp, date, scale_cost,
         margin_cost, forecast, ec):
     """gen is the set of generators in the project
     building is the set of buildings in the project
